==> telescope.1.4.zip: source/Telescope/include/Telescope.h <==
/*
 * Copyright (C) 2020 Activision Publishing, Inc.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above
 *    copyright notice, this list of conditions and the following
 *    disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above
 *    copyright notice, this list of conditions and the following
 *    disclaimer in the documentation and/or other materials
 *    provided with the distribution.
 *
 * 3. Neither the name of Activision Publishing, Inc. nor the names of
 *    its contributors may be used to endorse or promote products
 *    derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 */
#ifndef __TELESCOPE_H__
#define __TELESCOPE_H__

#include "PlatformFeatureDefs.h"
#include "ClientCallback.h"
#include "TelescopeJavascriptValue.h"
#include "TelescopeOperation.h"
#include "WebKit.h"
#include "TelescopeDll.h"
#include "TelescopeLib.h"
#include "TelescopeSurface.h"
#include "TelescopeViewParameter.h"
#include "WebView.h"
#include "TelescopeErrorCodes.h"
#include "MemoryTrackingScope.h"
#include "ClientWrappers/CompressionWrapperBase.h"
#include "ClientWrappers/HashingWrapperBase.h"
#include "ClientWrappers/CryptoWrapperBase.h"
#include "ClientWrappers/HttpWrapperBase.h"
#include "ClientWrappers/MemoryAllocatorBase.h"
#include "ClientWrappers/AssetLoaderWrapperBase.h"
#include "ClientWrappers/LogWrapperBase.h"
#include "ClientWrappers/ErrorHandlingWrapperBase.h"

#endif // __TELESCOPE_H__

==> telescope.1.15.zip: source/Telescope/include/Telescope.h <==
/*
 * Copyright (C) 2020 Activision Publishing, Inc.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above
 *    copyright notice, this list of conditions and the following
 *    disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above
 *    copyright notice, this list of conditions and the following
 *    disclaimer in the documentation and/or other materials
 *    provided with the distribution.
 *
 * 3. Neither the name of Activision Publishing, Inc. nor the names of
 *    its contributors may be used to endorse or promote products
 *    derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 */
#ifndef __TELESCOPE_H__
#define __TELESCOPE_H__

#include "PlatformFeatureDefs.h"
#include "ClientCallback.h"
#include "TelescopeJavascriptValue.h"
#include "TelescopeOperation.h"
#include "WebKit.h"
#include "TelescopeDll.h"
#include "TelescopeLib.h"
#include "TelescopeSurface.h"
#include "TelescopeViewParameter.h"
#include "WebView.h"
#include "TelescopeErrorCodes.h"
#include "MemoryTrackingScope.h"
#include "ClientWrappers/CompressionWrapperBase.h"
#include "ClientWrappers/HashingWrapperBase.h"
#include "ClientWrappers/CryptoWrapperBase.h"
#include "ClientWrappers/HttpWrapperBase.h"
#include "ClientWrappers/MemoryAllocatorBase.h"
#include "ClientWrappers/AssetLoaderWrapperBase.h"
#include "ClientWrappers/LogWrapperBase.h"
#include "ClientWrappers/ErrorHandlingWrapperBase.h"
#include "ClientWrappers/MediaPlayerWrapperBase.h"

#endif // #ifndef __TELESCOPE_H__
